<?php
/**
 * @file
 * Contains support form for miniOrange 2FA Login Module.
 */

 /**
 * Showing Support form info.
 */
 function mo_auth_login_settings($form, &$form_state) {
  global $base_url;
  $register_url = $base_url . '/admin/config/people/mo_auth/';
  $disabled=FALSE;
  if (!MoAuthUtilities::isCustomerRegistered()) {
    $disabled=TRUE;
    $form['header'] = array(
      '#markup' => '<div class="mo2f_configure_message">You need to <a href="'.$register_url.'" >Register/Login</a> using miniOrange account before using this module.</div>',
    );

    #return $form;
  }

  $form['header_top_style_1'] = array(
 	'#markup' => '<div class="mo_saml_table_layout_1"><div class="mo_saml_table_layout container">'
  );

  $loginSettings = new MoAuthLoginSettings();

  $form['mo_auth_enable_two_factor'] = array(
  	'#type' => 'checkbox',
  	'#value' => $loginSettings->getEnable2Factor(),
  	'#prefix' => '<div><div class="mo2f-setup-header"><div class="mo2f-setup-header-top-left">Enable Two-Factor module</div></div><div class="mo2f-info">',
  	'#suffix' => '</div></div>',
  	'#title' => t('Enable Two-Factor plugin. <span style="color:red;">(<b>If you disable this checkbox, Two-Factor module will not be invoked for any user during login.</b>)</span>'),
    '#disabled'=> $disabled,
  );

  $license_type = variable_get('mo_auth_2fa_license_type', 'DEMO');
  $is_free = $license_type == 'PREMIUM' || $license_type == 'DRUPAL_2FA_PLUGIN' ? FALSE : TRUE;

  $is_free_class = $is_free ? " mo2f-grayed-out" : "";
  $form['mo_auth_enforce_inline_registration'] = array(
  	'#type' => 'checkbox',
  	'#value' => $loginSettings->getEnforceInlineRegistration(),
  	'#prefix' => '<div><div class="mo2f-setup-header"><div class="mo2f-setup-header-top-left">Invoke Inline Registration to setup 2nd factor for users</div>
        <div style="float:right;display:inline-block;color:#0073aa;"><a href="?q=admin/config/people/mo_auth/licensing"><b>PREMIUM</b></a></div></div><div class="mo2f-info ' . $is_free_class . '">',
  	'#suffix' => '</div></div>',
  	'#disabled' => $is_free,
  	'#title' => t('Enforce 2 Factor registration for users at login time.'),
    '#states' => array(
    // Only enable this field when the 'mo_auth_enable_two_factor' checkbox is checked.
      'enabled' => array(
        ':input[name="mo_auth_enable_two_factor"]' => array(
          'checked' => TRUE && !$is_free,
        ),
      ),
    ),

  );

     $form['markup_idp_login_note'] = array(
         '#markup' => '<div class="mo_saml_highlight_background_note"><b>Note: </b>By default 2nd Factor is enabled after password authentication.
            If you do not want to remember passwords anymore and just login with 2nd Factor, please select below option.</div></br>',
     );

  $form['mo_auth_two_factor_instead_password'] = array(
    '#type' => 'checkbox',
    '#value' => $loginSettings->getEnableOTPinsteadPassword(),
    '#prefix' => '<div class="mo2f-setup-header"><div class="mo2f-setup-header-top-left">Select Login Screen Options</div><div style="float:right;display:inline-block;color:#0073aa;"><a href="?q=admin/config/people/mo_auth/licensing"><b>PREMIUM</b></a></div></div><div class="mo2f-info ' . $is_free_class . '"><div class="mo2f-info">',
    '#suffix' => '</div></div>',
    '#disabled' => $is_free,
    '#title' => t('Login with 2nd Factor only (<b>No password required.</b>)'),
    '#description' => 'NOTE: To use this feature make sure you have enabled the "ENFORCE 2 FACTOR REGISTRATION FOR USERS AT LOGIN TIME" feature</br></br></br>',
    '#states' => array(
    // Only enable this field when the 'mo_auth_enable_two_factor' checkbox is checked.
      'enabled' => array(
        ':input[name="mo_auth_enable_two_factor"]' => array(
          'checked' => TRUE && !$is_free,
        ),
      ),
    ),
  );

  $form['actions'] = array('#type' => 'actions');
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save Settings'),
    '#disabled' => $disabled,
  );

     $form['markup_idp_attr_header_top_div_close'] = array(
         '#markup' => '</div>',
     );

     MoAuthUtilities::addSupportForm($form, $form_state);

  return $form;
 }

 /**
  * Send support query.
  */
 function mo_auth_login_settings_submit($form, &$form_state) {
   $form_state['rebuild'] = TRUE;
   $enable2Factor = FALSE;
   $enforceInlineRegistration = FALSE;
   $enableOTP_instead_password = FALSE;

   if (array_key_exists('mo_auth_enable_two_factor', $form_state['input'])) {
      $enable2Factor = TRUE;
      if (array_key_exists('mo_auth_two_factor_instead_password', $form_state['input'])) {
        $enableOTP_instead_password = TRUE;
        $enforceInlineRegistration = TRUE;
      }
      if (array_key_exists('mo_auth_enforce_inline_registration', $form_state['input'])) {
        $enforceInlineRegistration = TRUE;
      }
    }

   $loginSettings = MoAuthLoginSettings::withValues($enable2Factor, $enforceInlineRegistration, $enableOTP_instead_password);
   $loginSettings->updateLoginSettings();
   drupal_set_message(t("Login settings updated."), 'status');
 }

/**
 * Send support query.
 */

function miniorange_2fa_send_query($form, &$form_state)
{
    $email = $form['miniorange_saml_email_address_support']['#value'];
    $phone = $form['miniorange_saml_phone_number_support']['#value'];
    $query = $form['miniorange_saml_support_query_support']['#value'];
    MoAuthUtilities::send_support_query($email, $phone, $query);
}